@@ -163,27 +163,27 @@ class CloudFrontToApiGateway(
 
         jsii.create(CloudFrontToApiGateway, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
-        return jsii.get(self, "apiGateway")
+        return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudFrontWebDistribution")
     def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
-        return jsii.get(self, "cloudFrontWebDistribution")
+        return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return jsii.get(self, "cloudFrontLoggingBucket")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="edgeLambdaFunctionVersion")
     def edge_lambda_function_version(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.Version]:
-        return jsii.get(self, "edgeLambdaFunctionVersion")
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Version], jsii.get(self, "edgeLambdaFunctionVersion"))
 
 
 @jsii.data_type(
@@ -226,7 +226,7 @@ class CloudFrontToApiGatewayProps:
         """
         result = self._values.get("existing_api_gateway_obj")
         assert result is not None, "Required property 'existing_api_gateway_obj' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_apigateway.RestApi, result)
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
@@ -235,7 +235,7 @@ class CloudFrontToApiGatewayProps:
         :default: - Default props are used
         """
         result = self._values.get("cloud_front_distribution_props")
-        return result
+        return typing.cast(typing.Any, result)
 
     @builtins.property
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
@@ -244,7 +244,7 @@ class CloudFrontToApiGatewayProps:
         :default: - true
         """
         result = self._values.get("insert_http_security_headers")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
